from ensure import ensure_annotations
from dummypackage12624.custom_exception import InvalidUserInput


@ensure_annotations
def addition(x: int, y: int) -> int:
    return x + y


@ensure_annotations
def subtraction(x: int, y: int) -> int:
    if (x - y) < 0:
        raise InvalidUserInput("Input2 >> Input1")
    else:
        return x - y


@ensure_annotations
def division(x: int, y: int) -> float:
    try:
        return x / y
    except Exception:
        raise InvalidUserInput("Invalid user input")

# something ....


# now no need to import like "import test_package.add import addition" directly we can import "from test_package import addition"
# add full import here and we can use shorthands while actually importing as package
from dummypackage12624.add import addition, subtraction, division
from dummypackage12624.custom_exception import InvalidUserInput